========================
 Invenio-REST v1.0.0a10
========================

Invenio-REST v1.0.0a10 was released on October 7, 2016.

About
-----

REST API module for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-rest==1.0.0a10

Documentation
-------------

   https://invenio-rest.readthedocs.io/

Happy hacking and thanks for flying Invenio-REST.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-rest
|   URL: http://inveniosoftware.org
